@@ -8,10 +8,14 @@ require 5.005_62;
 require Exporter;
 
 use Carp;
+
 use Config::IniFiles;
+
 use DateTime::Format::W3CDTF;
+
 use HTML::Entities::Interpolate;
 use HTML::Template;
+
 use version;
 
 our @ISA = qw(Exporter);
@@ -33,7 +37,7 @@ our @EXPORT = qw(
 
 );
 
-our $VERSION = '1.04';
+our $VERSION = '1.08';
 
 # ------------------------------------------------
 
@@ -45,7 +49,7 @@ our $VERSION = '1.04';
 	 _convert     => 0,
 	 _inFileName  => '',
 	 _outFileName => '',
-	 _pathForHTML => "$ENV{'HOME'}/httpd/prefork/htdocs/assets/templates/module/metadata/changes",
+	 _pathForHTML => '',
 	 _release     => '',
 	 _table       => 0,
 	 _urlForCSS   => '/assets/css/module/metadata/changes/ini.css',
@@ -521,8 +525,14 @@ sub report
 sub report_as_html
 {
 	my($self, @output) = @_;
-	my($template)      = HTML::Template -> new(path => $$self{'_pathForHTML'}, filename => 'ini.table.tmpl');
-	@output            = map
+
+	if (! $$self{'_pathForHTML'})
+	{
+		$$self{'_pathForHTML'} = '/var/www/assets/templates/module/metadata/changes';
+	}
+
+	my($template) = HTML::Template -> new(path => $$self{'_pathForHTML'}, filename => 'ini.table.tmpl');
+	@output       = map
 	{
 		{
 			th => $Entitize{$$_[0]},
@@ -544,7 +554,7 @@ sub report_as_html
 
 		$content = $template -> output();
 	}
-	
+
 	print $content;
 
 } # End of report_as_html.
@@ -673,7 +683,7 @@ C<Module::Metadata::Changes> - Manage a module's machine-readable C<Changelog.in
 	shell>ini.report.pl -h
 	shell>ini.report.pl -c
 	shell>ini.report.pl -r 1.23
-	shell>ini.report.pl -w > $HOME/httpd/prefork/htdocs/Changelog.html
+	shell>sudo ini.report.pl -w > /var/www/Changelog.html
 	shell>perl -MModule::Metadata::Changes -e 'Module::Metadata::Changes->new()->convert()'
 	shell>perl -MModule::Metadata::Changes -e 'print Module::Metadata::Changes->new()->read()->get_latest_version()'
 
@@ -730,10 +740,10 @@ The default is './Changelog.ini'.
 
 =item pathForHTML
 
-The default is "$ENV{'HOME'}/httpd/prefork/htdocs/assets/templates/module/metadata/changes".
-
 This is path to the HTML::Template-style templates used by the 'table' and 'webPage' options.
 
+The default is '/var/www/assets/templates/module/metadata/changes'.
+
 =item release
 
 The default is ''.
@@ -1265,40 +1275,19 @@ advise me on a suitable C<DateTime::Format::*> module to use.
 
 =back
 
-=head1 Required Modules
-
-=over 4
-
-=item use Carp
-
-=item DateTime::Format::HTTP
-
-=item DateTime::Format::Strptime
-
-=item DateTime::Format::W3CDTF
-
-=item HTML::Entities::Interpolate
-
-=item HTML::Template
-
-=item version
-
-=back
-
 =head1 See also
 
 C<Module::Changes>: http://search.cpan.org/dist/Module-Changes-0.05/
 
 =head1 Author
 
-C<Module::Metadata::Changes> was written by Ron Savage in 2008. [ron@savage.net.au]
+C<Module::Metadata::Changes> was written by Ron Savage I<E<lt>ron@savage.net.auE<gt>> in 2008.
 
 Home page: http://savage.net.au/index.html
 
 =head1 Copyright
 
-Australian copyright (c) 2008, Ron Savage. All rights reserved.
-
+Australian copyright (c) 2008, Ron Savage.
 	All Programs of mine are 'OSI Certified Open Source Software';
 	you can redistribute them and/or modify them under the terms of
 	The Artistic License, a copy of which is available at:
